Class: OpenapiClient::ManagementApi

Inherits:
Object
  • Object
show all
Defined in:
lib/openapi_client/api/management_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ManagementApi

Returns a new instance of ManagementApi.



19
20
21
# File 'lib/openapi_client/api/management_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/openapi_client/api/management_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#client(opts = {}) ⇒ ClientResponse

Client View client attributes

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:



26
27
28
29
# File 'lib/openapi_client/api/management_api.rb', line 26

def client(opts = {})
  data, _status_code, _headers = client_with_http_info(opts)
  data
end

#client_with_http_info(opts = {}) ⇒ Array<(ClientResponse, Integer, Hash)>

Client View client attributes

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(ClientResponse, Integer, Hash)>) —

    ClientResponse data, response status code and response headers



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/openapi_client/api/management_api.rb', line 35

def client_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagementApi.client ...'
  end
  # resource path
  local_var_path = '/2023-03-01/management/client'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ClientResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basic']

  new_options = opts.merge(
    :operation => :"ManagementApi.client",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagementApi#client\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#disconnect(opts = {}) ⇒ DisconnectResponse

Disconnect token Disconnect the token. A disconnected token will no longer return data. Data requests with a disconnected token will return a 403 Forbidden

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:



83
84
85
86
# File 'lib/openapi_client/api/management_api.rb', line 83

def disconnect(opts = {})
  data, _status_code, _headers = disconnect_with_http_info(opts)
  data
end

#disconnect_with_http_info(opts = {}) ⇒ Array<(DisconnectResponse, Integer, Hash)>

Disconnect token Disconnect the token. A disconnected token will no longer return data. Data requests with a disconnected token will return a 403 Forbidden

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(DisconnectResponse, Integer, Hash)>) —

    DisconnectResponse data, response status code and response headers



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/openapi_client/api/management_api.rb', line 92

def disconnect_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagementApi.disconnect ...'
  end
  # resource path
  local_var_path = '/2023-03-01/management/disconnect'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DisconnectResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['access-token']

  new_options = opts.merge(
    :operation => :"ManagementApi.disconnect",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagementApi#disconnect\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#introspect(opts = {}) ⇒ IntrospectResponse

Inspect token Retrieve data about the token, such as scopes, mode, provider, and if it is active

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:



140
141
142
143
# File 'lib/openapi_client/api/management_api.rb', line 140

def introspect(opts = {})
  data, _status_code, _headers = introspect_with_http_info(opts)
  data
end

#introspect_with_http_info(opts = {}) ⇒ Array<(IntrospectResponse, Integer, Hash)>

Inspect token Retrieve data about the token, such as `scopes`, `mode`, `provider`, and if it is active

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(IntrospectResponse, Integer, Hash)>) —

    IntrospectResponse data, response status code and response headers



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/openapi_client/api/management_api.rb', line 149

def introspect_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagementApi.introspect ...'
  end
  # resource path
  local_var_path = '/2023-03-01/management/introspect'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IntrospectResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['access-token']

  new_options = opts.merge(
    :operation => :"ManagementApi.introspect",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagementApi#introspect\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#token(token_request, opts = {}) ⇒ TokenResponse

Create token Exchange an authorization_code for an access_token after receiving on from the redirect_uri you specifiy after a successful user connection

Parameters:

  • token_request (TokenRequest)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:



198
199
200
201
# File 'lib/openapi_client/api/management_api.rb', line 198

def token(token_request, opts = {})
  data, _status_code, _headers = token_with_http_info(token_request, opts)
  data
end

#token_with_http_info(token_request, opts = {}) ⇒ Array<(TokenResponse, Integer, Hash)>

Create token Exchange an `authorization_code` for an `access_token` after receiving on from the `redirect_uri` you specifiy after a successful user connection

Parameters:

  • token_request (TokenRequest)
  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(TokenResponse, Integer, Hash)>) —

    TokenResponse data, response status code and response headers



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/openapi_client/api/management_api.rb', line 208

def token_with_http_info(token_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagementApi.token ...'
  end
  # verify the required parameter 'token_request' is set
  if @api_client.config.client_side_validation && token_request.nil?
    fail ArgumentError, "Missing the required parameter 'token_request' when calling ManagementApi.token"
  end
  # resource path
  local_var_path = '/2023-03-01/management/token'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(token_request)

  # return_type
  return_type = opts[:debug_return_type] || 'TokenResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"ManagementApi.token",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagementApi#token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tokens(opts = {}) ⇒ Array<Object>

Tokens View tokens and token status for respective client

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<Object>)


262
263
264
265
# File 'lib/openapi_client/api/management_api.rb', line 262

def tokens(opts = {})
  data, _status_code, _headers = tokens_with_http_info(opts)
  data
end

#tokens_with_http_info(opts = {}) ⇒ Array<(Array<Object>, Integer, Hash)>

Tokens View tokens and token status for respective client

Parameters:

  • opts (Hash) (defaults to: {}) —

    the optional parameters

Returns:

  • (Array<(Array<Object>, Integer, Hash)>) —

    Array data, response status code and response headers

    
    
    271
    272
    273
    274
    275
    276
    277
    278
    279
    280
    281
    282
    283
    284
    285
    286
    287
    288
    289
    290
    291
    292
    293
    294
    295
    296
    297
    298
    299
    300
    301
    302
    303
    304
    305
    306
    307
    308
    309
    310
    311
    312
    313
    # File 'lib/openapi_client/api/management_api.rb', line 271
    
    def tokens_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ManagementApi.tokens ...'
      end
      # resource path
      local_var_path = '/2023-03-01/management/tokens'
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body]
    
      # return_type
      return_type = opts[:debug_return_type] || 'Array<Object>'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['basic']
    
      new_options = opts.merge(
        :operation => :"ManagementApi.tokens",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ManagementApi#tokens\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #update_client(client_request, opts = {}) ⇒ ClientResponse

    Update client Update attributes of the client. Update the name, client_secret, or webhook_uri of the client

    Parameters:

    • client_request (ClientRequest)
    • opts (Hash) (defaults to: {}) —

      the optional parameters

    Returns:

    
    
    320
    321
    322
    323
    # File 'lib/openapi_client/api/management_api.rb', line 320
    
    def update_client(client_request, opts = {})
      data, _status_code, _headers = update_client_with_http_info(client_request, opts)
      data
    end

    #update_client_with_http_info(client_request, opts = {}) ⇒ Array<(ClientResponse, Integer, Hash)>

    Update client Update attributes of the client. Update the `name`, `client_secret`, or `webhook_uri` of the client

    Parameters:

    • client_request (ClientRequest)
    • opts (Hash) (defaults to: {}) —

      the optional parameters

    Returns:

    • (Array<(ClientResponse, Integer, Hash)>) —

      ClientResponse data, response status code and response headers

    
    
    330
    331
    332
    333
    334
    335
    336
    337
    338
    339
    340
    341
    342
    343
    344
    345
    346
    347
    348
    349
    350
    351
    352
    353
    354
    355
    356
    357
    358
    359
    360
    361
    362
    363
    364
    365
    366
    367
    368
    369
    370
    371
    372
    373
    374
    375
    376
    377
    378
    # File 'lib/openapi_client/api/management_api.rb', line 330
    
    def update_client_with_http_info(client_request, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ManagementApi.update_client ...'
      end
      # verify the required parameter 'client_request' is set
      if @api_client.config.client_side_validation && client_request.nil?
        fail ArgumentError, "Missing the required parameter 'client_request' when calling ManagementApi.update_client"
      end
      # resource path
      local_var_path = '/2023-03-01/management/client'
    
      # query parameters
      query_params = opts[:query_params] || {}
    
      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
    
      # form parameters
      form_params = opts[:form_params] || {}
    
      # http body (model)
      post_body = opts[:debug_body] || @api_client.object_to_http_body(client_request)
    
      # return_type
      return_type = opts[:debug_return_type] || 'ClientResponse'
    
      # auth_names
      auth_names = opts[:debug_auth_names] || ['basic']
    
      new_options = opts.merge(
        :operation => :"ManagementApi.update_client",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )
    
      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ManagementApi#update_client\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end